# Proposed workflow

1. Edit `setting.yaml` to correspond to your database system 
1. Draft a metadata file and put it into metadata folder (`~/.edam/metadata`)
2. Draft a template file (`~/.edam/templates`)
3. Add your input csv file into inputs folder (`~/.edam/inputs`)